pub trait Static: 'static + Sized { }Expand description
Safe trait that 'static types can implement to get a free blanket impl
of the Transient trait.
Implementing this trait results in a Transient implementation using Self
as the Static type and () as the Transience, which is almost certainly
what a 'static type would want.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.